Struct getAllowedCallsCall
pub struct getAllowedCallsCall {
pub account: Address,
pub keyId: Address,
}Expand description
Returns whether an account key is call-scoped and, if so, the configured call scopes.
@dev isScoped = false means unrestricted. isScoped = true && scopes.length == 0
means scoped deny-all.
@dev Missing, revoked, or expired access keys also return scoped deny-all so callers do
not observe stale persisted scope state.
Function with signature getAllowedCalls(address,address) and selector 0x0163e7ec.
function getAllowedCalls(address account, address keyId) external view returns (bool isScoped, CallScope[] memory scopes);Fields
account: AddresskeyId: AddressTrait Implementations
impl Clone for getAllowedCallsCall
impl Clone for getAllowedCallsCall
fn clone(&self) -> getAllowedCallsCall
fn clone(&self) -> getAllowedCallsCall
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for getAllowedCallsCall
impl Debug for getAllowedCallsCall
impl<'de> Deserialize<'de> for getAllowedCallsCall
impl<'de> Deserialize<'de> for getAllowedCallsCall
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getAllowedCallsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getAllowedCallsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for getAllowedCallsCall
impl JsonAbiExt for getAllowedCallsCall
impl JsonAbiExt for getAllowedCallsCall
fn abi() -> <getAllowedCallsCall as JsonAbiExt>::Abi
fn abi() -> <getAllowedCallsCall as JsonAbiExt>::Abi
impl PartialEq for getAllowedCallsCall
impl PartialEq for getAllowedCallsCall
fn eq(&self, other: &getAllowedCallsCall) -> bool
fn eq(&self, other: &getAllowedCallsCall) -> bool
self and other values to be equal, and is used by ==.impl Serialize for getAllowedCallsCall
impl Serialize for getAllowedCallsCall
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolCall for getAllowedCallsCall
impl SolCall for getAllowedCallsCall
type Parameters<'a> = (Address, Address)
type Parameters<'a> = (Address, Address)
type Token<'a> = <<getAllowedCallsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getAllowedCallsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Return = getAllowedCallsReturn
type Return = getAllowedCallsReturn
type ReturnTuple<'a> = (Bool, Array<CallScope>)
type ReturnTuple<'a> = (Bool, Array<CallScope>)
type ReturnToken<'a> = <<getAllowedCallsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getAllowedCallsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
fn new<'a>(
tuple: <<getAllowedCallsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getAllowedCallsCall
fn new<'a>( tuple: <<getAllowedCallsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getAllowedCallsCall
fn tokenize(&self) -> <getAllowedCallsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getAllowedCallsCall as SolCall>::Token<'_>
fn tokenize_returns(
ret: &<getAllowedCallsCall as SolCall>::Return,
) -> <getAllowedCallsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getAllowedCallsCall as SolCall>::Return, ) -> <getAllowedCallsCall as SolCall>::ReturnToken<'_>
fn abi_decode_returns(
data: &[u8],
) -> Result<<getAllowedCallsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getAllowedCallsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getAllowedCallsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getAllowedCallsCall as SolCall>::Return, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
impl StructuralPartialEq for getAllowedCallsCall